#
# The MIT License
#
# Copyright 2009 Canonical Ltd.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
"""Unit tests for OAuth Client"""
import unittest

from poauth.oauth import OAuthConsumer, OAuthToken
from poauth.client import OAuthRequest

class OAuthRequestTests(unittest.TestCase):
    '''Tests for OAuthRequest'''

    def test_parameters(self):
        '''Tests setting and getting a parameter.'''
        request = OAuthRequest()
        request.set_parameter('parameter', 'value')
        self.assertEquals(request.get_parameter('parameter'), 'value')

    def test_from_consumer_and_token(self):
        '''Test the from_consumer_and_token method.'''
        consumer = OAuthConsumer('consumer_key', 'consumer_secret')
        token = OAuthToken('token_key', 'token_secret')
        request = OAuthRequest.from_consumer_and_token(consumer,
                                                       token=token,
                                                       http_method='POST')
        self.assertTrue(isinstance(request, OAuthRequest))
        self.assertEquals(request.http_method, 'POST')
        self.assertEquals(request.token.key, token.key)
        self.assertEquals(request.consumer.key, consumer.key)

    def test_from_token_and_callback(self):
        '''Test the from_consumer_and_token method.'''
        token = OAuthToken('token_key', 'token_secret')
        request = OAuthRequest.from_token_and_callback(token,
                                                       http_method='POST')
        self.assertTrue(isinstance(request, OAuthRequest))
        self.assertEquals(request.http_method, 'POST')
        self.assertEquals(request.token.key, token.key)
